Changelog
==========

V.0.3.1 -- May 22, 2023
    * Change task result file name extension to .sgdata.

V.0.3.0 -- May 16, 2023
    * Move documentation to Github Pages.
    * Add boilerplate license header to source files.
    * Add the changelog and troubleshoot pages to documentation.



